@@ -19,18 +19,15 @@ override 'as_string' => sub {
     push @lines, $self->name() || croak "Empty name";
     push @lines, 'ALTID=' . $self->altID() if $self->can('altID') and $self->altID();
     push @lines, 'PID=' . join ',', @{ $self->pid() } if $self->can('pid') and $self->pid();
-    push @lines, 'TYPE="' . join( ',', map { uc $_ } @{ $self->types() } ) . '"'
+    push @lines, 'TYPE="' . join( ',', map {uc} @{ $self->types() } ) . '"'
         if ref $self->types() eq 'ARRAY' and $self->types()->[0];
     push @lines, 'PREF=' . $self->pref()          if $self->pref();
     push @lines, 'LANGUAGE=' . $self->language()  if $self->language();
     push @lines, 'LABEL="' . $self->label() . '"' if $self->label();
     push @lines, 'GEO="' . $self->geo() . '"'     if $self->geo();
 
-    my @values = ();
-    map { push @values, $self->_escape( $self->$_ ) } @order;
-    my $string = join( ';', @lines ) . ':' . join ';', @values;
+    my $string = join( ';', @lines ) . ':' . join ';', map { $self->_escape( $self->$_ ) } @order;
     return $self->fold($string);
-
 };
 
 __PACKAGE__->meta->make_immutable;
