@@ -18,10 +18,8 @@ override 'as_string' => sub {
     push @lines, 'LANGUAGE=' . $self->language()      if $self->language();
     push @lines, 'SORT-AS="' . $self->sort_as() . '"' if $self->sort_as();
 
-    my @values = map { $self->_escape($_) }
-        map { $self->$_ or $self->content() && $self->content()->{$_} } @order;
-
-    my $string = join( ';', @lines ) . ':' . join( ';', @values );
+    my @values = map { $self->$_ or $self->content() && $self->content()->{$_} } @order;
+    my $string = join( ';', @lines ) . ':' . join ';', map { $self->_escape($_) } @values;
     return $self->fold( $string, -force => 1 );
 };
 
